==> commons-utils-1.0.1.RELEASE-sources.jar: org/seppiko/commons/utils/Assert.java <==
/*
 * Copyright 2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils;

/**
 * Assert
 *
 * @author Leonard Woo
 */
public class Assert {

  public static void isTrue(boolean expression, String message) {
    if (!expression) {
      throw new IllegalArgumentException(message);
    }
  }

  public static void isFalse(boolean expression, String message) {
    if (expression) {
      throw new IllegalArgumentException(message);
    }
  }

  public static void isNull(Object obj, String message) {
    if (!ObjectUtil.isNull(obj)) {
      throw new IllegalArgumentException(message);
    }
  }

  public static void notNull(Object obj, String message) {
    if (!ObjectUtil.notNull(obj)) {
      throw new IllegalArgumentException(message);
    }
  }

  public static void hasLength(String text, String message) {
    if (!StringUtil.hasLength(text)) {
      throw new IllegalArgumentException(message);
    }
  }

  public static void hasText(String text, String message) {
    if (!StringUtil.hasText(text)) {
      throw new IllegalArgumentException(message);
    }
  }

  public static void notEmpty(Object[] array, String message) {
    if (ObjectUtil.isEmpty(array)) {
      throw new IllegalArgumentException(message);
    }
  }

}

==> commons-utils-1.0.3.RELEASE-sources.jar: org/seppiko/commons/utils/Assert.java <==
/*
 * Copyright 2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils;

/**
 * Assert
 *
 * @author Leonard Woo
 */
public class Assert {

  /**
   * if not true throw message
   *
   * @param expression boolean expression
   * @param message message
   */
  public static void isTrue(boolean expression, String message) {
    if (!expression) {
      throw new IllegalArgumentException(message);
    }
  }

  /**
   * if true throw message
   *
   * @param expression boolean expression
   * @param message message
   */
  public static void isFalse(boolean expression, String message) {
    if (expression) {
      throw new IllegalArgumentException(message);
    }
  }

  /**
   * if object is not null throw message
   *
   * @param obj object
   * @param message message
   */
  public static void isNull(Object obj, String message) {
    if (!ObjectUtil.isNull(obj)) {
      throw new IllegalArgumentException(message);
    }
  }

  /**
   * if object is null throw message
   *
   * @param obj object
   * @param message message
   */
  public static void notNull(Object obj, String message) {
    if (!ObjectUtil.notNull(obj)) {
      throw new IllegalArgumentException(message);
    }
  }

  /**
   * if string text length is 0 throw message
   *
   * @param text string text
   * @param message message
   */
  public static void hasLength(String text, String message) {
    if (!StringUtil.hasLength(text)) {
      throw new IllegalArgumentException(message);
    }
  }

  /**
   * if string text has not any char without whitespace throw message
   *
   * @param text string text
   * @param message message
   */
  public static void hasText(String text, String message) {
    if (!StringUtil.hasText(text)) {
      throw new IllegalArgumentException(message);
    }
  }

  /**
   * if object array is null or length is 0 throw message
   *
   * @param array object array
   * @param message message
   */
  public static void notEmpty(Object[] array, String message) {
    if (ObjectUtil.isEmpty(array)) {
      throw new IllegalArgumentException(message);
    }
  }

}
